@@ -1,6 +1,7 @@
 import scipy.stats as stats
 from UQpy.Distributions.baseclass import DistributionContinuous1D
 
+
 class ChiSquare(DistributionContinuous1D):
     """
     Chi-square distribution having probability density:
@@ -25,6 +26,6 @@ class ChiSquare(DistributionContinuous1D):
 
     * ``cdf``, ``pdf``, ``log_pdf``, ``icdf``, ``rvs``, ``moments``, ``fit``.
     """
-    def __init__(self, df, loc=0., scale=1):
+    def __init__(self, df, loc=0., scale=1.):
         super().__init__(df=df, loc=loc, scale=scale, order_params=('df', 'loc', 'scale'))
-        self._construct_from_scipy(scipy_name=stats.chi2)
\ No newline at end of file
+        self._construct_from_scipy(scipy_name=stats.chi2)
