@@ -1,6 +1,7 @@
 import scipy.stats as stats
 from UQpy.Distributions.baseclass import DistributionContinuous1D
 
+
 class Maxwell(DistributionContinuous1D):
     """
     Maxwell-Boltzmann distribution having probability density function
@@ -22,7 +23,7 @@ class Maxwell(DistributionContinuous1D):
     The following methods are available for ``Maxwell``:
     * ``cdf``, ``pdf``, ``log_pdf``, ``icdf``, ``rvs``, ``moments``, ``fit``.
     """
-    def __init__(self, loc=0, scale=1):
+    def __init__(self, loc=0., scale=1.):
         super().__init__(loc=loc, scale=scale, order_params=('loc', 'scale'))
         self._construct_from_scipy(scipy_name=stats.maxwell)
 
