@@ -2,6 +2,7 @@ import numpy as np
 import scipy.stats as stats
 from UQpy.Distributions.baseclass import DistributionContinuous1D
 
+
 class Normal(DistributionContinuous1D):
     """
     Normal distribution having probability density function
@@ -26,13 +27,12 @@ class Normal(DistributionContinuous1D):
         super().__init__(loc=loc, scale=scale, order_params=('loc', 'scale'))
         self._construct_from_scipy(scipy_name=stats.norm)
 
-    def fit(self, x):
-        x = self._check_x_dimension(x)
-        mle_loc, mle_scale = self.params['loc'], self.params['scale']
-        if mle_loc is None:
-            mle_loc = np.mean(x)
-        if mle_scale is None:
-            mle_scale = np.sqrt(np.mean((x - mle_loc) ** 2))
-        return {'loc': mle_loc, 'scale': mle_scale}
-
-
+    # This function was never accessed
+    #def fit(self, data):
+    #    data = self._check_x_dimension(data)
+    #    mle_loc, mle_scale = self.params['loc'], self.params['scale']
+    #    if mle_loc is None:
+    #        mle_loc = np.mean(data)
+    #    if mle_scale is None:
+    #        mle_scale = np.sqrt(np.mean((data - mle_loc) ** 2))
+    #    return {'loc': mle_loc, 'scale': mle_scale}
