@@ -24,8 +24,6 @@ class TruncNorm(DistributionContinuous1D):
 
     * ``cdf``, ``pdf``, ``log_pdf``, ``icdf``, ``rvs``, ``moments``, ``fit``.
     """
-    def __init__(self, a, b, loc=0, scale=1.):
+    def __init__(self, a, b, loc=0., scale=1.):
         super().__init__(a=a, b=b, loc=loc, scale=scale, order_params=('a', 'b', 'loc', 'scale'))
         self._construct_from_scipy(scipy_name=stats.truncnorm)
-
-
